:py:mod:`pytomography.io`
=========================

.. py:module:: pytomography.io

.. autoapi-nested-parse::

   This module contains functionality for data input/output in various data formats. It is organized primarily by imaging modality, and secondarily by data type



Subpackages
-----------
.. toctree::
   :titlesonly:
   :maxdepth: 3

   CT/index.rst
   PET/index.rst
   SPECT/index.rst
   shared/index.rst


